#
# spec file for package rdiff-backup-unstable
#
# Copyright (c) 2014 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           rdiff-backup-unstable
Version:        1.3.3
Release:        3.1
Summary:        Convenient and transparent local/remote incremental mirror/backup
License:        GPL-2.0+
Group:          Productivity/Archiving/Backup
Url:            http://www.nongnu.org/rdiff-backup/
# http://savannah.nongnu.org/download/rdiff-backup/rdiff-backup-%%{version}.tar.gz
Source0:        rdiff-backup-%{version}.tar.bz2
Source99:       %{name}-rpmlintrc
# PATCH-FIX-UPSTREAM rdiff-backup-unstable-fix-fsf-address.patch savannah#43706 malcolmlewis@opensuse.org -- Clean up FSF address rpmlint warnings.
Patch0:         rdiff-backup-unstable-fix-fsf-address.patch
Patch1:         http://pkgs.fedoraproject.org/cgit/rdiff-backup.git/tree/rdiff-backup-1.2.8-librsync-1.0.0.patch
%if 0%{?suse_version} <= 1130
BuildRequires:  librsync
%else
BuildRequires:  librsync-devel
%endif
BuildRequires:  perl
BuildRequires:  python-devel
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
Conflicts:      rdiff-backup
%py_requires

%description
rdiff-backup backs up one directory to another, possibly over a
network. The target directory ends up a copy of the source directory,
but extra reverse diffs are stored in a special subdirectory of that
target directory, so you can still recover files lost some time ago.
The idea is to combine the best features of a mirror and an incremental
backup. rdiff-backup also preserves subdirectories, hard links, dev
files, permissions, uid/gid ownership, and modification times. Also,
rdiff-backup can operate in a bandwidth efficient manner over a pipe,
like rsync. Thus you can use rdiff-backup and ssh to securely back a
hard drive up to a remote location, and only the differences will be
transmitted. Finally, rdiff-backup is easy to use and settings have
sensical defaults.

Note that this package contains the UNSTABLE version of rdiff-backup,
containing the latest features but potentially more bugs than the
stable one.

%prep
%setup -q -n "rdiff-backup-%{version}"
%patch0 -p1
%patch1 -p1

%build
export CFLAGS="%{optflags}"
python setup.py build

%install
python setup.py install \
    --prefix="%{_prefix}" \
    --root=%{buildroot} \
    --record-rpm=files.lst

perl -n -i -e 'print unless m|%{_mandir}|' files.lst

rm -rf "%{buildroot}%{_datadir}/doc/rdiff-backup-%{version}"
perl -n -i -e 'print unless m|%{_datadir}/doc|' files.lst

%files -f files.lst
%defattr(-, root, root)
%doc CHANGELOG COPYING FAQ.html examples.html README
%doc %{_mandir}/man1/*.1%{ext_man}

%changelog
* Sun Nov  1 2015 rpm@fthiessen.de
- Added rdiff-backup-1.2.8-librsync-1.0.0.patch from Fedora:
  * Fixes build on openSUSE Factory (librsync version 1.0.0)
* Wed Nov 26 2014 malcolmlewis@opensuse.org
- Change build requires to librsync-devel for builds >= 11.3.
- Add rdiff-backup-unstable-fix-fsf-address.patch: Clean up 36 FSF
  address rpmlint warnings savannah#43706.
* Sun Apr 11 2010 pascal.bleser@opensuse.org
- update to 1.3.3, forking rdiff-backup to rdiff-backup-unstable
* Thu Sep  3 2009 poeml@suse.de
- update to 1.2.8
  New in v1.2.8:
  * Improve handling of incorrect permissions on backup repository during restore
    operation. Closes Ubuntu bug #329722. (Andrew Ferguson)
  * Don't crash on zlib errors. Closes Debian bug #518531. (Andrew Ferguson)
  * Make sticky bit warnings quieter while determining file system abilities.
    Closes Savannah bug #25788. (Andrew Ferguson)
  * Fix situation where destination file cannot be opened because of an access
    error. Thanks to Dean Cording for the bug report. (Andrew Ferguson)
  * Fix --compare-hash options on Windows. Thanks to Serge Zub for the fix.
  New in v1.2.7:
  * Don't crash when filesystem can't set ACL. Thanks to Matt Thompson for the bug
    report. (Andrew Ferguson)
  * Properly disable hardlinks by default on Windows.
  * Fix Python 2.2 compatibility. Closes Savannah bug #25529. (Andrew Ferguson)
  * Fix typo which caused failure when checking if another rdiff-backup process is
    running on Windows. Thanks to Ryan Hughes for the bug report. (Andrew Ferguson)
* Fri Feb 13 2009 puzel@suse.cz
- update to 1.2.6
  - too many changes to be listed here, please see
    /usr/share/doc/packages/rdiff-backup/CHANGELOG
  for details
* Tue Aug 26 2008 cthiel@suse.de
- update to version 1.2.1
  * Produce a new binary for Windows which includes the Python for Windows
    Extensions.
  * Disable hardlinks by default when backup source or restore destination
    is on Windows.
  * Properly catch KeyboardInterrupt on Python 2.5.
  * Don't crash if a CacheIndexable tries to clear a non-existent cache
    entry, since the entry must already be cleared.
* Mon Aug  4 2008 cthiel@suse.de
- update to version 1.2.0
  * This is the new stable branch of rdiff-backup, representing almost three
    years of development releases. From the previous development release, this
    release includes two fixes for Unicode issues. From the previous stable
    release, this release features a large number of new features, including
    SHA1 checksums, native Windows support, improved Mac OS X and Cygwin
    support, better filesystem support for HFS+, NFS, SSHFS, SMB, CIFS, AFS,
    NTFS, and FAT32, and better handling of unreadable or pathological file
    permissions. It also includes the previously separate
    'rdiff-backup-statistics' tool.
* Tue Jan  9 2007 cthiel@suse.de
- fix ICC warning:  warning #592: variable "return_val" is used before its
  value is set (#232824)
* Mon Jan  8 2007 cthiel@suse.de
- update to version 1.0.5
  * Fix a traceback due to an off-by-1 error in "--remove-older-than nB".
  * Fix a security violation when restoring from a remote repository.
  * --list-at-time, --list-increments, and --list-increment-sizes should now
    work from a read-only repository.
* Mon Oct  2 2006 cthiel@suse.de
- fix build on older distributions
* Thu Sep 21 2006 cthiel@suse.de
- fix build with python 2.5
* Tue Feb 28 2006 jmatejek@suse.cz
- updated to reflect python changes due to #149809
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Jan 23 2006 cthiel@suse.de
- update to version 1.0.4
* Sat Nov 26 2005 cthiel@suse.de
- update to version 1.0.3
* Wed Oct 26 2005 cthiel@suse.de
- update to version 1.0.2
* Tue Sep 13 2005 cthiel@suse.de
- update to version 1.0.1
- specfile cleanup
* Wed Aug 17 2005 cthiel@suse.de
- update to version 1.0.0
* Sun Aug 14 2005 cthiel@suse.de
- use %%py_requires macro
* Tue May  3 2005 cthiel@suse.de
- use %%py_sitedir macro
* Fri Apr 15 2005 cthiel@suse.de
- initial creation of package (0.12.8)
